@@ -1,6 +1,6 @@
 package Ubic::Service;
 {
-  $Ubic::Service::VERSION = '1.40';
+  $Ubic::Service::VERSION = '1.41';
 }
 
 use strict;
@@ -8,7 +8,7 @@ use warnings;
 
 use Ubic::Settings;
 
-# ABSTRACT: interface and base class for any ubic service
+# ABSTRACT: interface and the base class for any ubic service
 
 
 use Ubic::Result qw(result);
@@ -101,11 +101,11 @@ __END__
 
 =head1 NAME
 
-Ubic::Service - interface and base class for any ubic service
+Ubic::Service - interface and the base class for any ubic service
 
 =head1 VERSION
 
-version 1.40
+version 1.41
 
 =head1 SYNOPSIS
 
@@ -117,67 +117,69 @@ version 1.40
 
 =head1 DESCRIPTION
 
-Ubic::Service is the abstract base class for all ubic service classes.
+C<Ubic::Service> is the abstract base class for all ubic service classes.
 
-It provides common API for implementing service start/stop operations, custom commands and tuning some metadata properties (C<user()>, C<group()>, C<check_period()>).
+It provides the common API for implementing start/stop/status operations, custom commands and tuning some metadata properties (C<user()>, C<group()>, C<check_period()>).
 
 =head1 METHODS
 
 =head2 ACTION METHODS
 
-All action methods should return L<Ubic::Result::Class> objects. If action method returns plain string, L<Ubic> will wrap it into result object too.
+All action methods should return L<Ubic::Result::Class> objects. If action method returns a plain string, L<Ubic> will wrap it into result object for you.
 
 =over
 
 =item B<start()>
 
-Start service. Should throw exception on failure and string with operation result otherwise.
+Start the service. Should throw an exception on failure and a result object or a string with operation result otherwise.
 
-Starting already running service should do nothing and return C<already running>.
+Starting an already running service should do nothing and return C<already running>.
 
 =item B<stop()>
 
-Stop service. Should throw exception on failure and string with operation result otherwise.
+Stop the service. Should throw an exception on failure and a result object or a string with operation result otherwise.
 
-Stopping already stopped service should do nothing and return C<not running>.
+Stopping an already stopped service should do nothing and return C<not running>.
 
 Successful stop of a service B<must> disable this service.
 
 =item B<status()>
 
-Check real status of service.
+Check the status of the service.
 
 It should check that service is running correctly and return C<running> if it is so.
 
 =item B<reload()>
 
-Reload service, if possible.
+Reload the service if possible.
+
+Throw an exception if reloading is not implemented (default implementation already does so).
 
 =back
 
 =head2 METADATA METHODS
 
-All metadata methods are read-only. All of them provide sane defaults.
+All metadata methods are read-only. All of them provide the sane defaults.
 
 =over
 
 =item B<port()>
 
-Get port number if service provides a server which uses TCP protocol.
+Get the port number if a service listens for a TCP port.
 
 Default is C<undef>.
 
 =item B<user()>
 
-Should return user from which the service can be controlled and will be running.
+Get the user from which the service can be controlled and will be running.
 
-Defaults to C<default_user> from L<Ubic::Settings> (i.e., C<root> for system-wide installations, or to the installation owner for local installations).
+Defaults to I<default_user> from L<Ubic::Settings> (i.e., C<root> for a system-wide installation, or to the installation owner for a local installation).
 
 =item B<group()>
 
-Get list of groups from which the service can be controlled and will be running.
+Get the list of groups from which the service can be controlled and will be running.
 
-First group from list will be used as real and effective group id, and other groups will be set as supplementary groups.
+First group from the list will be used as real and effective group id, and other groups will be set as supplementary groups.
 
 Default is an empty list, which will later be interpreted as default group of the user returned by C<user()> method.
 
@@ -185,15 +187,16 @@ Default is an empty list, which will later be interpreted as default group of th
 
 Period of checking a service by watchdog in seconds.
 
-Default is 60 seconds and it is unused by ubic-watchdog currently, so don't bother to override it by now :)
+Default is 60 seconds and it is unused by the B<ubic.watchdog> currently, so don't bother to override it by now :)
 
 =item B<check_timeout()>
 
-Timeout after which watchdog will give up on checking a service and kill itself.
+Timeout after which the watchdog will give up on checking the service and will kill itself.
 
-This parameter exists as a precaution against incorrectly implemented C<status()> or C<start()> methods. If C<status()> method hangs, without this timeout, watchdog would stay in memory forever and never get a chance to restart a service.
+This parameter exists as a precaution against incorrectly implemented C<status()> or C<start()> methods.
+If a C<status()> method hangs, without this timeout, watchdog would stay in memory forever and never get a chance to restart a service.
 
-This parameter is *not* a timeout for querying your service by HTTP or whatever your status check is. Service-specific timeouts should be configured by other means.
+This parameter is B<not> a timeout for querying your service by HTTP or whatever your status check is. Service-specific timeouts should be configured by other means.
 
 Default value is 60 seconds. It should not be changed unless you have a very good reason to do so (i.e., your service is so horribly slow that it can't start in 1 minute).
 
@@ -201,23 +204,26 @@ Default value is 60 seconds. It should not be changed unless you have a very goo
 
 =head2 CUSTOM COMMAND METHODS
 
-Services can define custom commands which don't fit into usual C<start/stop/restart/status> set.
+Services can define custom commands which don't fit into the usual C<start/stop/restart/status> set.
 
 =over
 
 =item B<custom_commands()>
 
-Can return list of service's custom commands, if such are exist.
+Get the list of service's custom commands, if there are any.
 
 =item B<do_custom_command($command)>
 
-Should execute specified command, if it is supported.
+Execute specified command, if it is supported. Throw an exception otherwise.
 
 =back
 
 =head2 NAME METHODS
 
-These methods usually should not be overriden by service classes. They are usually used by code which loads service (i.e. some L<Ubic::Multiservice>) to associate service with its name.
+These methods should not be overriden by specific service classes.
+They are usually used by the code which loads service (i.e. some kind of L<Ubic::Multiservice>) to associate service with its name.
+
+These methods are just the simple interdependent r/w accessors.
 
 =over
 
@@ -225,7 +231,7 @@ These methods usually should not be overriden by service classes. They are usual
 
 =item B<name($new_name)>
 
-Name of service.
+Get or set a name of the service.
 
 Each service with the same parent should have an unique name.
 
@@ -235,7 +241,7 @@ Service implementation classes shouldn't override this or other C<*_name> method
 
 =item B<full_name()>
 
-Fully qualified name of service.
+Get a fully qualified name of the service.
 
 Each service must have a unique full_name.
 
@@ -245,15 +251,15 @@ Full name is a concatenation of service's short C<name> and service's <parent_na
 
 =item B<parent_name($new_parent_name)>
 
-Get/set name of service's parent.
+Get or set a name of the service's parent.
 
-Service's loader (i.e. some kind of L<Ubic::Multiservice>) is responsible for calling this method immediately after service's construction as C<< $service->parent_name($self->full_name) >>.
+Service's loader (i.e. some kind of L<Ubic::Multiservice>) is responsible for calling this method immediately after a service is constructed, like this: C<< $service->parent_name($self->full_name) >> (check out L<Ubic::Multiservice> sources for more).
 
 =back
 
 =head1 FUTURE DIRECTIONS
 
-Current API for custom commands is inconvenient and don't support parameterized commands. It needs some refactoring.
+Current API for custom commands is inconvenient and doesn't support parameterized commands. It needs some refactoring.
 
 Requiring every service to inherit from this class can be seen as undesirable by some programmers, especially by those who prefer to use Moose and roles.
 If you know how to make this API more role-friendly without too much of converting pains, please contact us at ubic-perl@googlegroups.com or at irc://irc.perl.org#ubic.
@@ -264,7 +270,7 @@ L<Ubic::Service::Skeleton> - implement simple start/stop/status methods, and ubi
 
 L<Ubic::Service::Common> - just like Skeleton, but all code can be passed to constructor as sub references.
 
-L<Ubic::Service::SimpleDaemon> - give it any binary and it will make service from it.
+L<Ubic::Service::SimpleDaemon> - give it any binary and it will make a service from it.
 
 =head1 AUTHOR
 
